Crate coin_flip

Crate coin_flip 

Coin Flip

A library for flipping a coin and getting the result. Depends on rand “0.9.2”

Enums

Coin
Enum that defines the two coinflip variants Heads and Tails with discriminants

Functions

calculate_percentage
flip_coin
Flips a coin and returns the result takes an FnMut handler function that takes the result returns the result from the function